@@ -1,17 +1,32 @@
+default_parsers = [
+    'timestamp',
+    'relative-time',
+    'custom-formats',
+    'absolute-time',
+]
+
 settings = {
-    'PREFER_DATES_FROM': 'current_period',
-    'SUPPORT_BEFORE_COMMON_ERA': False,
-    'PREFER_DAY_OF_MONTH': 'current',
-    'SKIP_TOKENS': ["t"],
-    'SKIP_TOKENS_PARSER': ["t", "year", "hour", "minute"],
+    # Date order
+    'DATE_ORDER': 'MDY',
+    'PREFER_LOCALE_DATE_ORDER': True,
+
+    # Timezone related
     'TIMEZONE': 'local',
     'TO_TIMEZONE': False,
     'RETURN_AS_TIMEZONE_AWARE': 'default',
-    'NORMALIZE': True,
+
+    # Incomplete dates
+    'PREFER_DAY_OF_MONTH': 'current',
+    'PREFER_DATES_FROM': 'current_period',
     'RELATIVE_BASE': False,
-    'DATE_ORDER': 'MDY',
-    'PREFER_LOCALE_DATE_ORDER': True,
-    'FUZZY': False,
     'STRICT_PARSING': False,
+    'REQUIRE_PARTS': [],
+
+    # Language detection
+    'SKIP_TOKENS': ['t'],
+    'NORMALIZE': True,
+
+    # Other settings
     'RETURN_TIME_AS_PERIOD': False,
+    'PARSERS': default_parsers,
 }
