@@ -1,16 +1,14 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import unittest
 from datetime import datetime, timedelta
 from functools import wraps
 
-from mock import patch, Mock
+from unittest.mock import patch, Mock
 from parameterized import parameterized, param
 
 import dateparser.timezone_parser
 from dateparser.date import DateDataParser, date_parser
 from dateparser.date_parser import DateParser
+from dateparser.parser import _parse_absolute
 from dateparser.timezone_parser import StaticTzInfo
 from dateparser.utils import normalize_unicode
 
@@ -19,7 +17,7 @@ from tests import BaseTestCase
 
 class TestDateParser(BaseTestCase):
     def setUp(self):
-        super(TestDateParser, self).setUp()
+        super().setUp()
         self.parser = NotImplemented
         self.result = NotImplemented
         self.date_parser = NotImplemented
@@ -47,6 +45,8 @@ class TestDateParser(BaseTestCase):
         param('19 February 2013 year 09:10', datetime(2013, 2, 19, 9, 10)),
         param('21 January 2012 13:11:23.678', datetime(2012, 1, 21, 13, 11, 23, 678000)),
         param('1/1/16 9:02:43.1', datetime(2016, 1, 1, 9, 2, 43, 100000)),
+        param('29.02.2020 13.12', datetime(2020, 2, 29, 13, 12)),
+        param('Wednesday, 22nd June, 2016, 12.16 pm.', datetime(2016, 6, 22, 12, 16)),
         # French dates
         param('11 Mai 2014', datetime(2014, 5, 11)),
         param('dimanche, 11 Mai 2014', datetime(2014, 5, 11)),
@@ -108,6 +108,7 @@ class TestDateParser(BaseTestCase):
         param('18.10.14 um 22:56 Uhr', datetime(2014, 10, 18, 22, 56)),
         param('12-Mär-2014', datetime(2014, 3, 12)),
         param('Mit 13:14', datetime(2012, 11, 7, 13, 14)),
+        param('23. März 18.37 Uhr', datetime(2012, 3, 23, 18, 37)),
         # Czech dates
         param('pon 16. čer 2014 10:07:43', datetime(2014, 6, 16, 10, 7, 43)),
         param('13 Srpen, 2014', datetime(2014, 8, 13)),
@@ -150,7 +151,6 @@ class TestDateParser(BaseTestCase):
         param('1 Ni 2015', datetime(2015, 4, 1, 0, 0)),
         param('1 Mar 2015', datetime(2015, 3, 1, 0, 0)),
         param('1 сер 2015', datetime(2015, 8, 1, 0, 0)),
-        param('2016020417:10', datetime(2016, 2, 4, 17, 10)),
         # Chinese dates
         param('2015年04月08日10:05', datetime(2015, 4, 8, 10, 5)),
         param('2012年12月20日10:35', datetime(2012, 12, 20, 10, 35)),
@@ -178,7 +178,9 @@ class TestDateParser(BaseTestCase):
         param('12 जनवरी  1997 11:08 अपराह्न', datetime(1997, 1, 12, 23, 8)),
         # Georgian dates
         param('2011 წლის 17 მარტი, ოთხშაბათი', datetime(2011, 3, 17, 0, 0)),
-        param('2015 წ. 12 ივნ, 15:34', datetime(2015, 6, 12, 15, 34))
+        param('2015 წ. 12 ივნ, 15:34', datetime(2015, 6, 12, 15, 34)),
+        # Finnish dates
+        param('5.7.2018 5.45 ip.', datetime(2018, 7, 5, 17, 45))
     ])
     def test_dates_parsing(self, date_string, expected):
         self.given_parser(settings={'NORMALIZE': False,
@@ -188,6 +190,18 @@ class TestDateParser(BaseTestCase):
         self.then_period_is('day')
         self.then_date_obj_exactly_is(expected)
 
+    @parameterized.expand([
+        param('2016020417:10', datetime(2016, 2, 4, 17, 10)),
+    ])
+    def test_dates_parsing_no_spaces(self, date_string, expected):
+        self.given_parser(settings={'NORMALIZE': False,
+                                    'RELATIVE_BASE': datetime(2012, 11, 13),
+                                    'PARSERS': ['no-spaces-time']})
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_period_is('day')
+        self.then_date_obj_exactly_is(expected)
+
     def test_stringified_datetime_should_parse_fine(self):
         expected_date = datetime(2012, 11, 13, 10, 15, 5, 330256)
         self.given_parser(settings={'RELATIVE_BASE': expected_date})
@@ -388,7 +402,9 @@ class TestDateParser(BaseTestCase):
         param('Fri, 09 Sep 2005 13:51:39 -0700', 'GMT', datetime(2005, 9, 9, 20, 51, 39)),
         param('Fri, 09 Sep 2005 13:51:39 +0000', 'GMT', datetime(2005, 9, 9, 13, 51, 39)),
     ])
-    def test_dateparser_should_return_date_in_setting_timezone_if_timezone_info_present_both_in_datestring_and_given_in_settings(self, date_string, setting_timezone, expected):
+    def test_dateparser_should_return_date_in_setting_timezone_if_timezone_info_present_in_datestring_and_in_settings(
+        self, date_string, setting_timezone, expected
+    ):
         self.given_parser(settings={'TIMEZONE': setting_timezone})
         self.when_date_is_parsed(date_string)
         self.then_date_was_parsed_by_date_parser()
@@ -485,6 +501,44 @@ class TestDateParser(BaseTestCase):
         self.then_date_was_parsed_by_date_parser()
         self.then_date_obj_exactly_is(expected)
 
+    @parameterized.expand([
+        param('29 Feb', datetime(2020, 1, 1), datetime(2016, 2, 29)),
+        param('29/02', datetime(2020, 3, 30), datetime(2020, 2, 29)),
+        param('02/29', datetime(1702, 1, 1), datetime(1696, 2, 29)),
+    ])
+    def test_preferably_past_dates_leap_year(self, date_string, relative_base, expected):
+        self.given_parser(settings={'PREFER_DATES_FROM': 'past',
+                          'RELATIVE_BASE': relative_base})
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
+    @parameterized.expand([
+        param('29 Feb', datetime(2020, 1, 1), datetime(2020, 2, 29)),
+        param('29/02', datetime(2020, 3, 30), datetime(2024, 2, 29)),
+        param('02/29', datetime(1696, 3, 1), datetime(1704, 2, 29)),
+    ])
+    def test_preferably_future_dates_leap_year(self, date_string, relative_base, expected):
+        self.given_parser(settings={'PREFER_DATES_FROM': 'future',
+                                    'RELATIVE_BASE': relative_base})
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
+    @parameterized.expand([
+        param('29 Feb', datetime(2020, 1, 1), datetime(2020, 2, 29)),
+        param('29/02', datetime(2020, 3, 30), datetime(2020, 2, 29)),
+        param('29 Feb', datetime(1702, 3, 1), datetime(1704, 2, 29)),
+        param('02/29', datetime(1699, 3, 1), datetime(1696, 2, 29)),
+    ])
+    def test_dates_without_preference_leap_year(self, date_string, relative_base, expected):
+        self.given_local_tz_offset(0)
+        self.given_parser(settings={'PREFER_DATES_FROM': 'current_period',
+                                    'RELATIVE_BASE': relative_base})
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
     @parameterized.expand([
         param('February 2015', today=datetime(2015, 1, 31), expected=datetime(2015, 2, 28)),
         param('February 2012', today=datetime(2015, 1, 31), expected=datetime(2012, 2, 29)),
@@ -599,6 +653,11 @@ class TestDateParser(BaseTestCase):
         param('16:10', expected=datetime(2015, 2, 15, 16, 10), period='day'),
         param('2014', expected=datetime(2014, 2, 15), period='year'),
         param('2008', expected=datetime(2008, 2, 15), period='year'),
+        # subscript and superscript dates
+        param('²⁰¹⁵', expected=datetime(2015, 2, 15), period='year'),
+        param('²⁹/⁰⁵/²⁰¹⁵', expected=datetime(2015, 5, 29), period='day'),
+        param('₁₅/₀₂/₂₀₂₀', expected=datetime(2020, 2, 15), period='day'),
+        param('₃₁ December', expected=datetime(2015, 12, 31), period='day'),
     ])
     def test_extracted_period(self, date_string, expected=None, period=None):
         self.given_local_tz_offset(0)
@@ -674,9 +733,6 @@ class TestDateParser(BaseTestCase):
         param('10/9/1914 03:07:09.788888 pm', expected=datetime(1914, 10, 9, 15, 7, 9, 788888),
               order='MDY'),
         param('1-8-09 07:12:49 AM', expected=datetime(2009, 1, 8, 7, 12, 49), order='MDY'),
-        param('201508', expected=datetime(2015, 8, 20, 0, 0), order='DYM'),
-        param('201508', expected=datetime(2020, 8, 15, 0, 0), order='YDM'),
-        param('201108', expected=datetime(2008, 11, 20, 0, 0), order='DMY'),
         param('2016 july 13.', expected=datetime(2016, 7, 13, 0, 0), order='YMD'),
         param('16 july 13.', expected=datetime(2016, 7, 13, 0, 0), order='YMD'),
         param('Sunday 23 May 1856 12:09:08 AM', expected=datetime(1856, 5, 23, 0, 9, 8),
@@ -688,12 +744,27 @@ class TestDateParser(BaseTestCase):
         self.then_date_was_parsed_by_date_parser()
         self.then_date_obj_exactly_is(expected)
 
+    @parameterized.expand([
+        param('201508', expected=datetime(2015, 8, 20, 0, 0), order='DYM'),
+        param('201508', expected=datetime(2020, 8, 15, 0, 0), order='YDM'),
+        param('201108', expected=datetime(2008, 11, 20, 0, 0), order='DMY'),
+    ])
+    def test_order_no_spaces(self, date_string, expected=None, order=None):
+        self.given_parser(settings={'DATE_ORDER': order, 'PARSERS': ['no-spaces-time']})
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
     @parameterized.expand([
         param('10.1.2019', expected=datetime(2019, 1, 10, 0, 0), languages=['de'],
               settings={'PREFER_DAY_OF_MONTH': 'first'}),
         param('10.1.2019', expected=datetime(2019, 1, 10, 0, 0), languages=['de']),
         param('10.1.2019', expected=datetime(2019, 10, 1, 0, 0),
               settings={'DATE_ORDER': 'MDY'}),
+        param('03/11/2559 05:13', datetime(2559, 3, 11, 5, 13), languages=["th"],
+              settings={"DATE_ORDER": "MDY"}),
+        param('03/15/2559 05:13', datetime(2559, 3, 15, 5, 13), languages=["th"],
+              settings={"DATE_ORDER": "MDY"})
     ])
     def test_if_settings_provided_date_order_is_retained(
         self, date_string, expected=None, languages=None, settings=None
@@ -745,7 +816,7 @@ class TestDateParser(BaseTestCase):
 
     def when_date_is_parsed_by_date_parser(self, date_string):
         try:
-            self.result = DateParser().parse(date_string)
+            self.result = DateParser().parse(date_string, parse_method=_parse_absolute)
         except Exception as error:
             self.error = error
 
