@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 from datetime import datetime, timedelta
 from pytz import timezone
 
-from mock import Mock, patch
+from unittest.mock import Mock, patch
 from parameterized import parameterized, param
 
 import dateparser.timezone_parser
@@ -13,7 +12,7 @@ from tests import BaseTestCase
 
 class TestTZPopping(BaseTestCase):
     def setUp(self):
-        super(TestTZPopping, self).setUp()
+        super().setUp()
         self.initial_string = self.datetime_string = self.timezone_offset = NotImplemented
 
     @parameterized.expand([
@@ -47,6 +46,10 @@ class TestTZPopping(BaseTestCase):
         param('April 10, 2016 at 12:00:00 UTC-09:30', -9.5),
         param('Thu, 24 Nov 2016 16:03:00 UT', 0),
         param('Fri Sep 23 2016 10:34:51 GMT+0800 (CST)', 8),
+        param('Fri Sep 23 2016 10:34:51 GMT+12', 12),
+        param('Fri Sep 23 2016 10:34:51 UTC+13', 13),
+        param('Fri Sep 23 2016 10:34:51 GMT+1245 (CST)', 12.75),
+        param('Fri Sep 23 2016 10:34:51 UTC+1245', 12.75),
         param('2019-07-17T12:30:00.000-03:30', -3.5),
         param('2019-07-17T12:30:00.000-02:30', -2.5),
     ])
@@ -95,7 +98,7 @@ class TestTZPopping(BaseTestCase):
 
 class TestLocalTZOffset(BaseTestCase):
     def setUp(self):
-        super(TestLocalTZOffset, self).setUp()
+        super().setUp()
         self.timezone_offset = NotImplemented
 
     @parameterized.expand([
@@ -137,7 +140,7 @@ class TestLocalTZOffset(BaseTestCase):
 
 class TestTimeZoneConversion(BaseTestCase):
     def setUp(self):
-        super(TestTimeZoneConversion, self).setUp()
+        super().setUp()
         self.settings = {}
         self.parser = parse
         self.result = NotImplemented
@@ -164,9 +167,10 @@ class TestTimeZoneConversion(BaseTestCase):
     def then_date_is(self, date):
         self.assertEqual(date, self.result)
 
+
 class TestStaticTzInfo(BaseTestCase):
     def setUp(self):
-        super(TestStaticTzInfo, self).setUp()
+        super().setUp()
 
     @parameterized.expand([
         param(given_date=datetime(2007, 1, 18, tzinfo=timezone('UTC'))),
